@@ -182,7 +182,7 @@ def serialize_warning_message(warning_message):
         message_module = type(warning_message.message).__module__
         message_class_name = type(warning_message.message).__name__
         message_args = warning_message.message.args
-        message_str = None
+        message_str = str(warning_message.message)
     else:
         message_str = warning_message.message
         message_module = None
@@ -234,6 +234,7 @@ def remote_initconfig(option_dict, args):
     config.option.dist = "no"
     config.option.distload = False
     config.option.numprocesses = None
+    config.option.maxprocesses = None
     config.args = args
     return config
 
